@@ -13,8 +13,8 @@
 // Load main frame
 //============================================================================
 define([
-    '!!text-loader!vp_base/html/mainFrame.html', // LAB: text! to text-loader
-    'vp_base/css/mainFrame.css', // LAB: css! to css-loader
+    '!!text-loader!vp_base/html/mainFrame.html', // INTEGRATION: unified version of text loader
+    'vp_base/css/mainFrame.css', // INTEGRATION: unified version of css loader
 
     // load module
     './com/com_Config',
@@ -226,9 +226,7 @@ define([
         //========================================================================
         renderMainFrame() {
             this.$pageDom = $(vpHtml);
-            if (vpConfig.extensionType === 'lab') {
-                this.$pageDom.addClass('lab');
-            }
+            this.$pageDom.addClass(vpConfig.extensionType);
             return this.$pageDom;
         }
         afterAttach() {
@@ -542,8 +540,7 @@ define([
                     that.boardFrame.hideLoadingBar();
                     that.boardFrame.reloadBlockList();
                 } else {
-                    // LAB: require -> requirejs changed module to require to avoid error : Cannot statically analyse 'require(…, …)'
-                    requirejs(loadMenuList, function() {
+                    window.require(loadMenuList, function() {
                         let parentBlock = null;
                         let prevBlock = null;
                         loadStateList.forEach(obj => {
