@@ -13,7 +13,7 @@
 // [CLASS] DataPrep
 //============================================================================
 define([
-    '!!text-loader!vp_base/html/m_ml/model.html', // LAB: text! to text-loader
+    '!!text-loader!vp_base/html/m_ml/model.html', // INTEGRATION: unified version of text loader
     'vp_base/js/com/com_util',
     'vp_base/js/com/com_interface',
     'vp_base/js/com/com_String',
